@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2021 Red Hat, Inc.  All rights reserved.
+ * Copyright (C) 2012-2023 Red Hat, Inc.  All rights reserved.
  *
  * Author: Fabio M. Di Nitto <fabbione@kronosnet.org>
  *
@@ -144,7 +144,7 @@ static int crypto_use_config(
 		knet_h->sec_salt_size = 0;
 	}
 
-	force_pmtud_run(knet_h, KNET_SUB_CRYPTO, 1);
+	force_pmtud_run(knet_h, KNET_SUB_CRYPTO, 1, 0);
 
 	return 0;
 }
@@ -199,7 +199,7 @@ static int crypto_init(
 	}
 
 	log_debug(knet_h, KNET_SUB_CRYPTO,
-		  "Initizializing crypto module [%s/%s/%s]",
+		  "Initializing crypto module [%s/%s/%s]",
 		  knet_handle_crypto_cfg->crypto_model,
 		  knet_handle_crypto_cfg->crypto_cipher_type,
 		  knet_handle_crypto_cfg->crypto_hash_type);
