@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2021 Red Hat, Inc.  All rights reserved.
+ * Copyright (C) 2010-2023 Red Hat, Inc.  All rights reserved.
  *
  * Authors: Fabio M. Di Nitto <fabbione@kronosnet.org>
  *          Federico Simoncelli <fsimon@kronosnet.org>
@@ -399,7 +399,7 @@ typedef struct knet_transport_ops {
  *  1 retry
  *    any sleep or wait action should happen inside the transport code
  */
-	int (*transport_tx_sock_error)(knet_handle_t knet_h, int sockfd, int recv_err, int recv_errno);
+	int (*transport_tx_sock_error)(knet_handle_t knet_h, int sockfd, int subsys, int recv_err, int recv_errno);
 
 /*
  * this function is called on _every_ received packet
