@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2021 Red Hat, Inc.  All rights reserved.
+ * Copyright (C) 2016-2023 Red Hat, Inc.  All rights reserved.
  *
  * Authors: Fabio M. Di Nitto <fabbione@kronosnet.org>
  *
@@ -23,27 +23,27 @@
 
 static void test(void)
 {
-	knet_handle_t knet_h;
+	knet_handle_t knet_h1, knet_h[2];
 	struct rlimit cur;
 	int logfds[2];
 
 	printf("Test knet_handle_new hostid 1, no logging\n");
 
-	knet_h = knet_handle_new_ex(1, 0, 0, 0);
-	if (!knet_h) {
+	knet_h1 = knet_handle_new_ex(1, 0, 0, 0);
+	if (!knet_h1) {
 		printf("Unable to init knet_handle! err: %s\n", strerror(errno));
 		exit(FAIL);
 	}
 
-	if (knet_handle_free(knet_h) != 0) {
+	if (knet_handle_free(knet_h1) != 0) {
 		printf("Unable to free knet_handle\n");
 		exit(FAIL);
 	}
 
 	printf("Test knet_handle_new hostid -1, no logging\n");
 
-	knet_h = knet_handle_new_ex(-1, 0, 0, 0);
-	if (!knet_h) {
+	knet_h1 = knet_handle_new_ex(-1, 0, 0, 0);
+	if (!knet_h1) {
 		printf("Unable to init knet_handle! err: %s\n", strerror(errno));
 		exit(FAIL);
 	}
@@ -52,13 +52,13 @@ static void test(void)
 	 * -1 == knet_node_id_t 65535
 	 */
 
-	if (knet_h->host_id != 65535) {
+	if (knet_h1->host_id != 65535) {
 		printf("host_id size might have changed!\n");
-		knet_handle_free(knet_h);
+		knet_handle_free(knet_h1);
 		exit(FAIL);
 	}
 
-	if (knet_handle_free(knet_h) != 0) {
+	if (knet_handle_free(knet_h1) != 0) {
 		printf("Unable to free knet_handle\n");
 		exit(FAIL);
 	}
@@ -73,16 +73,16 @@ static void test(void)
 	 */
 	printf("Test knet_handle_new hostid 1, incorrect log_fd (-1)\n");
 
-	knet_h = knet_handle_new(1, -1, 0);
+	knet_h1 = knet_handle_new(1, -1, 0);
 
-	if ((!knet_h) && (errno != EINVAL)) {
+	if ((!knet_h1) && (errno != EINVAL)) {
 		printf("knet_handle_new returned incorrect errno on incorrect log_fd\n");
 		exit(FAIL);
 	}
 
-	if (knet_h) {
+	if (knet_h1) {
 		printf("knet_handle_new accepted an incorrect (-1) log_fd\n");
-		knet_handle_free(knet_h);
+		knet_handle_free(knet_h1);
 		exit(FAIL);
 	}
 
@@ -91,11 +91,11 @@ static void test(void)
 	 */
 	printf("Test knet_handle_new hostid 1, incorrect log_fd (max_fd + 1)\n");
 
-	knet_h = knet_handle_new(1, (int) cur.rlim_max, 0);
+	knet_h1 = knet_handle_new(1, (int) cur.rlim_max, 0);
 
-	if ((knet_h) || (errno != EINVAL)) {
+	if ((knet_h1) || (errno != EINVAL)) {
 		printf("knet_handle_new accepted an incorrect (max_fd + 1) log_fd or returned incorrect errno on incorrect log_fd: %s\n", strerror(errno));
-		knet_handle_free(knet_h);
+		knet_handle_free(knet_h1);
 		exit(FAIL);
 	}
 
@@ -103,23 +103,17 @@ static void test(void)
 
 	printf("Test knet_handle_new hostid 1, proper log_fd, invalid log level (DEBUG + 1)\n");
 
-	knet_h = knet_handle_new(1, logfds[1], KNET_LOG_DEBUG + 1);
-
-	if ((knet_h) || (errno != EINVAL)) {
+	knet_h1 = knet_handle_new(1, logfds[1], KNET_LOG_DEBUG + 1);
+	if ((knet_h1) || (errno != EINVAL)) {
 		printf("knet_handle_new accepted an incorrect log level or returned incorrect errno on incorrect log level: %s\n", strerror(errno));
-		knet_handle_free(knet_h);
-		flush_logs(logfds[0], stdout);
-		close_logpipes(logfds);
-		exit(FAIL);
+		knet_h[1] = knet_h1;
+		CLEAN_EXIT(FAIL);
 	}
 
 	printf("Test knet_handle_new hostid 1, proper log_fd, proper log level (DEBUG)\n");
 
-	knet_h = knet_handle_start(logfds, KNET_LOG_DEBUG);
-
-	knet_handle_free(knet_h);
-	flush_logs(logfds[0], stdout);
-	close_logpipes(logfds);
+	(void)knet_handle_start(logfds, KNET_LOG_DEBUG, knet_h);
+	CLEAN_EXIT(CONTINUE);
 }
 
 int main(int argc, char *argv[])
